@@ -11,7 +11,7 @@ use HTTP::Request();
 use HTTP::Response();
 use POSIX();
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub _CHUNK_SIZE                { return 4096 }
 sub _FILE_READ_SIZE            { return 8192 }
@@ -470,7 +470,7 @@ sub _get_request_headers {
         $request_headers =
             $request->method() . q[ ]
           . $request->uri()->path_query() . q[ ]
-          . ( $request->protocol() // 'HTTP/1.1' )
+          . ( $request->protocol() || 'HTTP/1.1' )
           . "${CRLF}Host: $http_host$CRLF"
           . $request->headers()->as_string($CRLF)
           . $CRLF;
@@ -708,7 +708,7 @@ Net::ICAP::Client - A client implementation of the ICAP (RFC 3507) protocol
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =head1 SYNOPSIS
 
@@ -725,7 +725,7 @@ Version 0.01
 
 =head1 DESCRIPTION
 
-This module provides a client interface to an L<ICAP (RFC 3507) Server|http://tools.ietf.org/html/rfc3507>.  ICAP Servers are designed to inspect and modify HTTP Request and Responses before the 
+This module provides a client interface to an L<ICAP (RFC 3507) Server|http://tools.ietf.org/html/rfc3507>.  ICAP Servers are designed to inspect and modify HTTP Request and Responses before the Request is passed to backend systems or the Response goes back to the user.
 
 =head1 SUBROUTINES/METHODS
 
@@ -734,7 +734,7 @@ This module provides a client interface to an L<ICAP (RFC 3507) Server|http://to
     my $icap = Net::ICAP::Client->new('icap://icap-proxy.example.com/');
     my $icap = Net::ICAP::Client->new('icaps://icap-proxy.example.com/', SSL_ca_path => '/path/to/ca-bundle.crt', %other_IO_SSL_Socket_options);
 
-By default, the SSL_verifycn_scheme, SSL_verifycn_name, SSL_verify_mode and 
+By default, the SSL_verifycn_scheme, SSL_verifycn_name and SSL_verify_mode parameters are automatically set for icaps URIs, but these parameters may be overridden.
 
 =head2 debug
 
